Included are functions for multivariate statistical methods, tools for diagnostics, multivariate calibration, cross validation and bootstrap, clustering, etc.
P. Filzmoser <P.Filzmoser@tuwien.ac.at
| Package: | chemometrics |
| Type: | Package |
| Version: | 0.1 |
| Date: | 2007-11-09 |
| License: | GPL (>= 2) |
The package can be used to verify the examples in the book. It can also be used to analyze own data.
K. Varmuza and P. Filzmoser: Introduction to Multivariate Statistical Analysis in Chemometrics. CRC Press, Boca Raton, FL, 2009.