30 objects (Wild growing, flowering Hyptis suaveolens) and 7 variables
(chemotypes), and 2 variables that explain the grouping (4 groups).
Usage
data(hyptis)
Arguments
Format
A data frame with 30 observations on the following 9 variables.
Sabinene
a numeric vector
Pinene
a numeric vector
Cineole
a numeric vector
Terpinene
a numeric vector
Fenchone
a numeric vector
Terpinolene
a numeric vector
Fenchol
a numeric vector
Location
a factor with levels East-highEast-lowNorthSouth
Group
a numeric vector with the group information
Details
This data set can be used for cluster analysis.
References
P. Grassi, M.J. Nunez, K. Varmuza, and C. Franz:
Chemical polymorphism of essential oils of Hyptis suaveolens from El Salvador.
Flavour \& Fragrance, 20, 131-135, 2005.
K. Varmuza and P. Filzmoser: Introduction to Multivariate Statistical Analysis
in Chemometrics. CRC Press, Boca Raton, FL, 2009