Learn R Programming

chemometrics (version 1.3.9)

lmCV: Repeated Cross Validation for lm

Description

Repeated Cross Validation for multiple linear regression: a cross-validation is performed repeatedly, and standard evaluation measures are returned.

Usage

lmCV(formula, data, repl = 100, segments = 4, segment.type = c("random", "consecutive", "interleaved"), length.seg, trace = FALSE, ...)

Arguments

formula
formula, like y~X, i.e., dependent~response variables
data
data set including y and X
repl
number of replication for Cross Validation
segments
number of segments used for splitting into training and test data
segment.type
"random", "consecutive", "interleaved" splitting into training and test data
length.seg
number of parts for training and test data, overwrites segments
trace
if TRUE intermediate results are reported
...
additional plotting arguments

Value

residuals
matrix of size length(y) x repl with residuals
predicted
matrix of size length(y) x repl with predicted values
SEP
Standard Error of Prediction computed for each column of "residuals"
SEPm
mean SEP value
RMSEP
Root MSEP value computed for each column of "residuals"
RMSEPm
mean RMSEP value

Details

Repeating the cross-validation with allow for a more careful evaluation.

References

K. Varmuza and P. Filzmoser: Introduction to Multivariate Statistical Analysis in Chemometrics. CRC Press, Boca Raton, FL, 2009.

See Also

mvr

Examples

Run this code
data(ash)
set.seed(100)
res=lmCV(SOT~.,data=ash,repl=10)
hist(res$SEP)

Run the code above in your browser using DataLab