lassoCV(formula, data, K = 10, fraction = seq(0, 1, by = 0.05), trace = FALSE, plot.opt = TRUE, sdfact = 2, legpos = "topright", ...)lars.
The optimal fraction is chosen according to the following criterion:
Within the CV scheme, the mean of the SEPs is computed, as well as their standard errors. Then one
searches for the minimum of the mean SEPs and adds sdfact*standarderror. The optimal fraction
is the smallest fraction with an MSEP below this bound.cv.lars, lassocoefdata(PAC)
res=lassoCV(y~X,data=PAC,K=5,fraction=seq(0.1,0.5,by=0.1))Run the code above in your browser using DataLab